| Title: | An Amazing Shiny App |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | firstname lastname [aut, cre] |
| Maintainer: | firstname lastname <[email protected]> |
| License: | What license is it under? |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-16 09:29:38 UTC |
| Source: | https://github.com/m-murphy/eppicenter.tools |
Run the Shiny Application
run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )run_app( onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |